@@ -59,35 +59,32 @@ void show_game_over_dialog() {
     gtk_dialog_add_buttons (GTK_DIALOG (dialog),
 			    GTK_STOCK_UNDO, GTK_RESPONSE_REJECT,
 			    NULL);
-  /* FIXME: New and New Game are both used. One is a stock item, the
-   * other is more descriptive. */
   gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+			  GTK_STOCK_QUIT, GTK_RESPONSE_CLOSE,
                           _("New Game"), GTK_RESPONSE_ACCEPT,
                           NULL);
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
 
   /* add a stock icon? */ 
   switch (gtk_dialog_run (GTK_DIALOG (dialog)))
-  {
+    {
     case GTK_RESPONSE_ACCEPT: 
-      {
-        gtk_widget_destroy (dialog);
-        new_game (NULL, NULL);
-      }
+      gtk_widget_destroy (dialog);
+      new_game (NULL, NULL);
       break;
     case GTK_RESPONSE_REJECT:
-      {
-        gtk_widget_destroy (dialog);
-	game_over = FALSE;
-	undo_callback ();
-      }
+      timer_restart ();
+      gtk_widget_destroy (dialog);
+      game_over = FALSE;
+      undo_callback ();
+      break;
+    case GTK_RESPONSE_CLOSE:
+      gtk_main_quit ();
       break;
     default:
-     {
-       /* The player closed the dialog window, just ignore this. */
-       game_over = FALSE;
-       gtk_widget_destroy (dialog);
-     }
+      /* The player closed the dialog window, just ignore this. */
+      game_over = FALSE;
+      gtk_widget_destroy (dialog);
   }
 }
 
@@ -427,9 +424,9 @@ void show_rules_options_dialog ()
 		
 		gtk_dialog_add_buttons(GTK_DIALOG(option_dialog),
 		                       GTK_STOCK_OK,
-													 GTK_RESPONSE_OK,
-													 GTK_STOCK_CANCEL,
-													 GTK_RESPONSE_CANCEL);
+				       GTK_RESPONSE_OK,
+				       GTK_STOCK_CANCEL,
+				       GTK_RESPONSE_CANCEL, NULL);
 
     gtk_window_set_transient_for (GTK_WINDOW (option_dialog), GTK_WINDOW (app));
 		gtk_window_set_modal(GTK_WINDOW(option_dialog), TRUE);
