@@ -2,7 +2,7 @@
 
 /* gnome-stones - preferences.h
  *
- * Time-stamp: <2003-08-02 04:29:58 callum>
+ * Time-stamp: <2004/07/18 16:12:47 callum>
  *
  * Copyright (C) 1998, 2003 Carsten Schaar
  *
@@ -447,6 +447,7 @@ preferences_restore (void)
 
   cave = gconf_client_get_int (get_gconf_client (),
                                KEY_START_CAVE, NULL);
+
   if (!default_game || !load_game_by_name (default_game, 0))
     {
       if (def || !load_game_by_name (filename, cave))
@@ -460,7 +461,6 @@ preferences_restore (void)
                                              _("Neither your chosen game nor the default game could be loaded."),
                                              _("Please make sure that GNOME Stones is correctly installed."),
                                              _("You may be able to select a different game from the preferences dialog."));
-            gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
             gtk_label_set_use_markup (GTK_LABEL (GTK_MESSAGE_DIALOG (dialog)->label),
                                       TRUE);
             gtk_dialog_run (GTK_DIALOG (dialog));
@@ -584,11 +584,13 @@ preferences_set_joystick_switch_level (GtkAdjustment *adjust, gpointer data)
 static void
 preferences_set_scroll_method (GtkWidget *widget, gpointer data)
 {
-  set_scroll_method ((gchar *)data);
+  gchar * names[3] = { "atari_scroll", "smooth_scroll", "center_scroll" };
+  
+  set_scroll_method (names[gtk_combo_box_get_active (GTK_COMBO_BOX (widget))]);
   gconf_set_scroll_method (scroll_method_name ());
 }
 
-
+#if 0
 static void
 enable_sound_callback (GtkWidget *widget, gpointer *data)
 {
@@ -599,7 +601,7 @@ enable_sound_callback (GtkWidget *widget, gpointer *data)
   set_sound_enabled (is_on);
   gconf_set_sound_enabled (is_on);
 }
-
+#endif
 
 static GtkWidget *
 preferences_dialog_new (void)
@@ -610,9 +612,13 @@ preferences_dialog_new (void)
   GtkWidget *list_view;
   GtkWidget *label;
   GtkWidget *scrolled;
+#if 0
   GtkWidget *frame;
   GtkWidget *fv;
+#endif
+#if 0
   GtkWidget *enable_sound_toggle_button;
+#endif
   GtkListStore *list;
   GtkTreeIter iter;
   GtkTreeSelection *selection;
@@ -753,9 +759,7 @@ preferences_dialog_new (void)
     GtkWidget *scale;
     GtkWidget *hbox;
     GtkWidget *vbox;
-    GtkWidget *menuitem;
     GtkWidget *optionmenu;
-    GtkWidget *device_menu;
 #if 0
     GList     *devices;
 #endif
@@ -771,17 +775,16 @@ preferences_dialog_new (void)
     label= gtk_label_new (_("Joystick device:"));
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, GNOME_PAD_SMALL);
 
-    device_menu= gtk_menu_new ();
+    optionmenu= gtk_combo_box_new_text ();    
 
     /* We definatly have a "disable" entry.  */
-    menuitem= gtk_menu_item_new_with_label (_("disabled"));
+    gtk_combo_box_append_text (GTK_COMBO_BOX (optionmenu), _("disabled"));
 
 #if 0
     g_signal_connect (GTK_OBJECT (menuitem), "activate",
 			(GtkSignalFunc) preferences_set_joystick_device,
 			GUINT_TO_POINTER (GDK_CORE_POINTER));
 #endif
-    gtk_menu_shell_append (GTK_MENU_SHELL (device_menu), menuitem);
 
 #if 0    
     for (devices = gdk_input_list_devices (), i= 1; devices; 
@@ -804,8 +807,6 @@ preferences_dialog_new (void)
 	  gtk_menu_set_active (GTK_MENU (device_menu), i);
       }
 #endif    
-    optionmenu= gtk_option_menu_new ();
-    gtk_option_menu_set_menu (GTK_OPTION_MENU (optionmenu), device_menu);
     gtk_box_pack_start (GTK_BOX (hbox), optionmenu, FALSE, FALSE, 2);
 
     frame= games_frame_new (_("Digital joystick emulation"));
@@ -849,7 +850,7 @@ preferences_dialog_new (void)
   box = gtk_vbox_new (FALSE, GNOME_PAD);
   gtk_container_set_border_width (GTK_CONTAINER (box), GNOME_PAD_SMALL);
   
-
+#if 0
   frame = games_frame_new (_("Sound"));
   fv = gtk_vbox_new (FALSE, FALSE);
   gtk_box_set_spacing (GTK_BOX (fv), 6);
@@ -869,11 +870,12 @@ preferences_dialog_new (void)
                     G_CALLBACK (enable_sound_callback), NULL);
   
   gtk_container_add (GTK_CONTAINER(fv), enable_sound_toggle_button);
-  
+
   label = gtk_label_new_with_mnemonic (_("_Sound"));
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook),
 			    box, label);
 
+#endif  
 
   /* Fourth page is miscellaneous stuff */
   
@@ -883,13 +885,10 @@ preferences_dialog_new (void)
 
   
   {
-    gint      i=0;
     GtkWidget *frame;
     GtkWidget *hbox;
     GtkWidget *vbox;
-    GtkWidget *menuitem;
     GtkWidget *optionmenu;
-    GtkWidget *scroll_method_menu;
 
 
     frame= games_frame_new (_("Scroll method"));
@@ -905,48 +904,30 @@ preferences_dialog_new (void)
     label= gtk_label_new (_("Scroll method:"));
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, GNOME_PAD_SMALL);
     */
-    
-    scroll_method_menu= gtk_menu_new ();
 
+    optionmenu= gtk_combo_box_new_text ();
+    
 
     prdata->scroll_method_name = scroll_method_name();
 
-    menuitem= gtk_menu_item_new_with_label (_("Atari like scrolling"));
-
-    g_signal_connect (GTK_OBJECT (menuitem), "activate",
-			(GtkSignalFunc) preferences_set_scroll_method,
-			"atari_scroll");
-    gtk_menu_shell_append (GTK_MENU_SHELL (scroll_method_menu), menuitem);
-
-
+    gtk_combo_box_append_text (GTK_COMBO_BOX (optionmenu),
+                               _("Atari like scrolling"));
     if (!strcmp(prdata->scroll_method_name,"atari_scroll"))
-      gtk_menu_set_active (GTK_MENU (scroll_method_menu), i++);
-    ++i;
-
-
-    menuitem= gtk_menu_item_new_with_label (_("Smooth scrolling"));
-    g_signal_connect (GTK_OBJECT (menuitem), "activate",
-			(GtkSignalFunc) preferences_set_scroll_method,
-			"smooth_scroll");
-    gtk_menu_shell_append (GTK_MENU_SHELL (scroll_method_menu), menuitem);
-
+      gtk_combo_box_set_active (GTK_COMBO_BOX (optionmenu), 0);
+    gtk_combo_box_append_text (GTK_COMBO_BOX (optionmenu),
+                               _("Smooth scrolling"));
     if (!strcmp(prdata->scroll_method_name,"smooth_scroll"))
-      gtk_menu_set_active (GTK_MENU (scroll_method_menu), i++);
-    ++i;
-
-
-    menuitem= gtk_menu_item_new_with_label (_("Always in the center"));
-    g_signal_connect (GTK_OBJECT (menuitem), "activate",
-			(GtkSignalFunc) preferences_set_scroll_method,
-			"center_scroll");
-    gtk_menu_shell_append (GTK_MENU_SHELL (scroll_method_menu), menuitem);
-
+      gtk_combo_box_set_active (GTK_COMBO_BOX (optionmenu), 1);
+    gtk_combo_box_append_text (GTK_COMBO_BOX (optionmenu),
+                               _("Always in the center"));
     if (!strcmp(prdata->scroll_method_name,"center_scroll"))
-      gtk_menu_set_active (GTK_MENU (scroll_method_menu), i);
-    ++i;
+      gtk_combo_box_set_active (GTK_COMBO_BOX (optionmenu), 2);
+    
+    
+    g_signal_connect (GTK_OBJECT (optionmenu), "changed",
+			(GtkSignalFunc) preferences_set_scroll_method,
+			NULL);
    
-    optionmenu= gtk_option_menu_new ();
-    gtk_option_menu_set_menu (GTK_OPTION_MENU (optionmenu), scroll_method_menu);
     gtk_box_pack_start (GTK_BOX (hbox), optionmenu, FALSE, FALSE, 2);
   }
 
@@ -987,10 +968,10 @@ session_management_init (void)
   GnomeClient *client= gnome_master_client ();
   
   g_signal_connect (GTK_OBJECT (client), "save_yourself",
-		      GTK_SIGNAL_FUNC (preferences_save_local), 
-		      GINT_TO_POINTER (FALSE));
+		    GTK_SIGNAL_FUNC (preferences_save_local), 
+		    GINT_TO_POINTER (FALSE));
   g_signal_connect (GTK_OBJECT (client), "die",
-		      GTK_SIGNAL_FUNC (quit_cb), NULL);
+		    GTK_SIGNAL_FUNC (quit_cb), NULL);
 }
 
 
