@@ -46,7 +46,7 @@ struct _MoveHistory
 
 void new_game_cb (GtkWidget *widget, gpointer data);
 void new_net_game_cb (GtkWidget *widget, gpointer data);
-gboolean quit_game_cb (GtkWidget *widget, gpointer data);
+void quit_game_cb (GtkWidget *widget, gpointer data);
 void undo_move_cb (GtkWidget *widget, gpointer data);
 void redo_move_cb (GtkWidget *widget, gpointer data);
 void black_level_cb (GtkWidget *widget, gpointer data);
@@ -58,7 +58,6 @@ void quick_moves_cb (GtkWidget *widget, gpointer data);
 void anim_cb (GtkWidget *widget, gpointer data);
 void anim_stagger_cb (GtkWidget *widget, gpointer data);
 void load_tiles_cb (GtkWidget *widget, gpointer data);
-void fill_menu (GtkWidget *menu);
 void set_selection (GtkWidget *widget, void *data);
 void free_str (GtkWidget *widget, void *data);
 void load_tiles_callback (GtkWidget *widget, void *data);
@@ -80,6 +79,4 @@ void properties_cb (GtkWidget *widget, gpointer data);
 void set_bg_color (void);
 void gui_draw_grid (void);
 
-extern guint whose_turn, game_in_progress;
-
 #endif
